@@ -2,11 +2,11 @@ import asyncio
 import base64
 import pickle
 import sys
-from typing import Any, Optional
+from typing import Any
 
 import pydash
 
-from ..constants.queue_constant import QUEUE_NAME
+from ..constants.queue_constant import QUEUE_CONCURRENCY, QUEUE_MAX_ATTEMP, QUEUE_NAME
 from ..loggers.logger import logger
 from ..tasks.storage import list_tasks
 from ..type_dicts.queue_option_type import QueueOption
@@ -17,13 +17,12 @@ class Queue:
 
     def __init__(self, redis: Any, options: QueueOption):
         self.redis = redis
-        self.queue_name = options.get('queue_name') or QUEUE_NAME
-        self.concurrency = options.get('concurrency') or 10
-        self.max_attempt = options.get('max_attempt') or 3
+        self.concurrency = options.get('concurrency') or QUEUE_CONCURRENCY
+        self.max_attempt = options.get('max_attempt') or QUEUE_MAX_ATTEMP
 
     async def __get_queue(self):
         if len(self.running_tasks) <= self.concurrency:
-            detail = await self.redis.rpop(self.queue_name)
+            detail = await self.redis.rpop(QUEUE_NAME)
             if detail:
                 task = asyncio.create_task(self.__process_queue(detail))
                 self.running_tasks.add(task)
@@ -75,29 +74,14 @@ class Queue:
         print("Add to list")
         return await self.redis.lpush(key, value)
 
-    async def add_to_queue(self, name: str, data: Any, queue_name: Optional[str] = None):
+    async def add_to_queue(self, name: str, data: Any):
         if "pytest" in sys.modules:
             return
 
-        if not queue_name:
-            queue_name = self.queue_name
-
         await self.__add_to_list(
-            queue_name,
-            base64.b64encode(pickle.dumps({"name": name, "data": data, "attempt": 0})),
-        )
-
-    async def add_class_to_queue(self, name: str, data: Any, queue_name: Optional[str] = None):
-        if "pytest" in sys.modules:
-            return
-
-        if not queue_name:
-            queue_name = self.queue_name
-
-        await self.__add_to_list(
-            queue_name,
+            "queue",
             base64.b64encode(pickle.dumps({"name": name, "data": data, "attempt": 0})),
         )
 
     async def add_queue(self, options):
-        await self.__add_to_list(self.queue_name, base64.b64encode(pickle.dumps(options)))
+        await self.__add_to_list("queue", base64.b64encode(pickle.dumps(options)))
